#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <unistd.h>

#include <glib/gi18n.h>
#include <gtk/gtk.h>

static void
invoke_launchpad_integration (const char *mode)
{
    const char *argv[] = { "launchpad-integration", NULL,
			   "--pid", NULL, NULL };
    pid_t pid;
    GError *error = NULL;

    argv[1] = mode;
    argv[3] = g_strdup_printf ("%ld", (long)getpid());

    if (!g_spawn_async (NULL, argv, NULL,
			G_SPAWN_SEARCH_PATH,
			NULL, NULL, NULL, &error)) {
	/* XXX - jamesh 2005-07-08
         * This should really spawn a dialog
	 */
	g_warning ("error occurred during spawn: %s", error->message);
	g_error_free (error);
    }
    g_free (argv[3]);
}

void
launchpad_integration_show_info (void)
{
    invoke_launchpad_integration ("--info");
}

void
launchpad_integration_show_translations (void)
{
    invoke_launchpad_integration ("--translations");
}

void
launchpad_integration_show_bugs (void)
{
    invoke_launchpad_integration ("--bugs");
}

/* -------------------------- */

static GtkActionEntry actions[] = {
    { "LaunchpadAppInfo", NULL, N_("Launchpad Info"),
      NULL, NULL, G_CALLBACK (launchpad_integration_show_info) },
    { "LaunchpadAppTranslations", NULL, N_("Translate This Application ..."),
      NULL, NULL, G_CALLBACK (launchpad_integration_show_translations) },
    { "LaunchpadAppBugs", NULL, N_("Report a Bug"),
      NULL, NULL, G_CALLBACK (launchpad_integration_show_bugs) },
};

GtkActionGroup*
launchpad_integration_get_action_group (void)
{
    static GtkActionGroup *action_group;

    if (!action_group) {
	action_group = gtk_action_group_new ("LaunchpadIntegration");
	// gtk_action_group_set_translation_domain (action_group, PACKAGE);
	gtk_action_group_add_actions (action_group,
				      actions, G_N_ELEMENTS (actions),
				      NULL);
    }
    return action_group;
}
